@@ -1,5 +1,5 @@
-# ifndef __JACKAL_TYPES_H
-# define __JACKAL_TYPES_H
+#ifndef __JACKALOPE_TYPES_H
+#define __JACKALOPE_TYPES_H
 
 
 /*
@@ -10,7 +10,7 @@
  ********************************************************
  */
 
-
+#include "jackalope_config.h" // controls debugging and diagnostics output
 
 #include <RcppArmadillo.h>
 #include <cstdint>
@@ -20,6 +20,7 @@
 #include "pcg/pcg_extras.hpp"  // pcg 128-bit integer type
 
 
+
 using namespace Rcpp;
 
 typedef uint_fast8_t uint8;
@@ -31,5 +32,10 @@ typedef pcg_extras::pcg128_t uint128;
 
 
 
+namespace jlp {
+const std::string bases = "TCAG";
+}
+
+
 
 #endif
